@@ -1084,9 +1084,13 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
       ExceptionInfo
         *sans_exception;
 
+      /*
+        Search for a default font.
+      */
       sans_exception=AcquireExceptionInfo();
-      type_info=GetTypeInfoByFamily((const char *) NULL,draw_info->style,
-        draw_info->stretch,draw_info->weight,sans_exception);
+      if (type_info == (const TypeInfo *) NULL)
+        type_info=GetTypeInfoByFamily((const char *) NULL,draw_info->style,
+          draw_info->stretch,draw_info->weight,sans_exception);
       if (type_info == (const TypeInfo *) NULL)
         type_info=GetTypeInfo("*",sans_exception);
       sans_exception=DestroyExceptionInfo(sans_exception);
@@ -1433,7 +1437,7 @@ static void FreetypeFree(FT_Memory magick_unused(memory),void *block)
   (void) RelinquishMagickMemory(block);
 }
 
-static FT_Memory FreetypeAcquireMemoryManager()
+static FT_Memory FreetypeAcquireMemoryManager(void)
 {
   FT_Memory
     memory;
@@ -1940,8 +1944,12 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
           (draw_info->stroke.alpha == (MagickRealType) TransparentAlpha) &&
           (draw_info->stroke_pattern == (Image *) NULL)) ? MagickTrue :
           MagickFalse;
-        image_view=AcquireAuthenticCacheView(image,exception);
         r=bitmap->bitmap.buffer;
+        image_view=AcquireAuthenticCacheView(image,exception);
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+        #pragma omp parallel for schedule(static) shared(status) \
+          magick_number_threads(image,image,bitmap->bitmap.rows,4)
+#endif
         for (y=0; y < (ssize_t) bitmap->bitmap.rows; y++)
         {
           double
@@ -2105,6 +2113,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   const char *magick_unused(encoding),const PointInfo *offset,
   TypeMetric *metrics,ExceptionInfo *exception)
 {
+  magick_unreferenced(encoding);
   (void) ThrowMagickException(exception,GetMagickModule(),
     MissingDelegateWarning,"DelegateLibrarySupportNotBuiltIn","'%s' (Freetype)",
     draw_info->font != (char *) NULL ? draw_info->font : "none");
@@ -2211,7 +2220,8 @@ static MagickBooleanType RenderPostscript(Image *image,
     unique_file;
 
   MagickBooleanType
-    identity;
+    identity,
+    status;
 
   PointInfo
     extent,
@@ -2385,7 +2395,12 @@ static MagickBooleanType RenderPostscript(Image *image,
         (void) SetImageAlphaChannel(annotate_image,OpaqueAlphaChannel,
           exception);
       fill_color=draw_info->fill;
+      status=MagickTrue;
       annotate_view=AcquireAuthenticCacheView(annotate_image,exception);
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+      #pragma omp parallel for schedule(static) shared(status) \
+        magick_number_threads(annotate_image,annotate_image,annotate_image->rows,4)
+#endif
       for (y=0; y < (ssize_t) annotate_image->rows; y++)
       {
         ssize_t
@@ -2394,10 +2409,15 @@ static MagickBooleanType RenderPostscript(Image *image,
         Quantum
           *magick_restrict q;
 
+        if (status == MagickFalse)
+          continue;
         q=GetCacheViewAuthenticPixels(annotate_view,0,y,annotate_image->columns,
           1,exception);
         if (q == (Quantum *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         for (x=0; x < (ssize_t) annotate_image->columns; x++)
         {
           GetFillColor(draw_info,x,y,&fill_color,exception);
@@ -2410,7 +2430,7 @@ static MagickBooleanType RenderPostscript(Image *image,
         }
         sync=SyncCacheViewAuthenticPixels(annotate_view,exception);
         if (sync == MagickFalse)
-          break;
+          status=MagickFalse;
       }
       annotate_view=DestroyCacheView(annotate_view);
       (void) CompositeImage(image,annotate_image,OverCompositeOp,MagickTrue,
