@@ -85,7 +85,7 @@
   Forward declarations
 */
 static MagickBooleanType
-  SetImageProfileInternal(Image *,const char *,const StringInfo *,
+  SetImageProfileInternal(Image *,const char *,StringInfo *,
     const MagickBooleanType,ExceptionInfo *);
 
 static void
@@ -633,8 +633,7 @@ static inline void SetLCMSInfoScale(LCMSInfo *info,const double scale)
 }
 #endif
 
-static MagickBooleanType SetsRGBImageProfile(Image *image,
-  ExceptionInfo *exception)
+static void SetsRGBImageProfile(Image *image,ExceptionInfo *exception)
 {
   static unsigned char
     sRGBProfile[] =
@@ -912,18 +911,13 @@ static MagickBooleanType SetsRGBImageProfile(Image *image,
   StringInfo
     *profile;
 
-  MagickBooleanType
-    status;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
   if (GetImageProfile(image,"icc") != (const StringInfo *) NULL)
-    return(MagickFalse);
-  profile=AcquireStringInfo(sizeof(sRGBProfile));
-  SetStringInfoDatum(profile,sRGBProfile);
-  status=SetImageProfile(image,"icc",profile,exception);
-  profile=DestroyStringInfo(profile);
-  return(status);
+    return;
+  profile=BlobToProfileStringInfo("icc",sRGBProfile,sizeof(sRGBProfile),
+    exception);
+  (void) SetImageProfilePrivate(image,profile,exception);
 }
 
 MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
@@ -981,10 +975,12 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
     Add a ICC, IPTC, or generic profile to the image.
   */
   status=MagickTrue;
-  profile=AcquireStringInfo((size_t) length);
+  profile=AcquireProfileStringInfo(name,(size_t) length,exception);
+  if (profile == (StringInfo *) NULL)
+    return(MagickFalse);
   SetStringInfoDatum(profile,(unsigned char *) datum);
   if ((LocaleCompare(name,"icc") != 0) && (LocaleCompare(name,"icm") != 0))
-    status=SetImageProfile(image,name,profile,exception);
+    status=SetImageProfilePrivate(image,profile,exception);
   else
     {
       const StringInfo
@@ -1000,10 +996,10 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           value=GetImageProperty(image,"exif:ColorSpace",exception);
           (void) value;
           if (LocaleCompare(value,"1") != 0)
-            (void) SetsRGBImageProfile(image,exception);
+            SetsRGBImageProfile(image,exception);
           value=GetImageProperty(image,"exif:InteroperabilityIndex",exception);
           if (LocaleCompare(value,"R98.") != 0)
-            (void) SetsRGBImageProfile(image,exception);
+            SetsRGBImageProfile(image,exception);
           icc_profile=GetImageProfile(image,"icc");
         }
       if ((icc_profile != (const StringInfo *) NULL) &&
@@ -1053,7 +1049,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           }
         if ((cmsGetDeviceClass(source_info.profile) != cmsSigLinkClass) &&
             (icc_profile == (StringInfo *) NULL))
-          status=SetImageProfile(image,name,profile,exception);
+          status=SetImageProfilePrivate(image,profile,exception);
         else
           {
             CacheView
@@ -1147,8 +1143,10 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
                     source_info.scale[0]=100.0;
                     source_info.scale[1]=255.0;
                     source_info.scale[2]=255.0;
+#if !defined(MAGICKCORE_HDRI_SUPPORT)
                     source_info.translate[1]=(-0.5);
                     source_info.translate[2]=(-0.5);
+#endif
                   }
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
                 else
@@ -1241,8 +1239,10 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
                     target_info.scale[0]=0.01;
                     target_info.scale[1]=1/255.0;
                     target_info.scale[2]=1/255.0;
+#if !defined(MAGICKCORE_HDRI_SUPPORT)
                     target_info.translate[1]=0.5;
                     target_info.translate[2]=0.5;
+#endif
                   }
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
                 else
@@ -1432,7 +1432,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             transform=DestroyTransformTLS(transform);
             if ((status != MagickFalse) &&
                 (cmsGetDeviceClass(source_info.profile) != cmsSigLinkClass))
-              status=SetImageProfile(image,name,profile,exception);
+              status=SetImageProfilePrivate(image,profile,exception);
             if (target_info.profile != (cmsHPROFILE) NULL)
               (void) cmsCloseProfile(target_info.profile);
           }
@@ -1441,7 +1441,6 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
       }
 #endif
     }
-  profile=DestroyStringInfo(profile);
   return(status);
 }
 
@@ -1790,11 +1789,10 @@ static void GetProfilesFromResourceBlock(Image *image,
         /*
           IPTC profile.
         */
-        profile=AcquireStringInfo((size_t) count);
-        SetStringInfoDatum(profile,p);
-        (void) SetImageProfileInternal(image,"iptc",profile,MagickTrue,
-          exception);
-        profile=DestroyStringInfo(profile);
+        profile=BlobToProfileStringInfo("iptc",p,(size_t) count,exception);
+        if (profile != (StringInfo *) NULL)
+          (void) SetImageProfileInternal(image,GetStringInfoName(profile),
+            profile,MagickTrue,exception);
         p+=count;
         break;
       }
@@ -1811,11 +1809,10 @@ static void GetProfilesFromResourceBlock(Image *image,
         /*
           ICC Profile.
         */
-        profile=AcquireStringInfo((size_t) count);
-        SetStringInfoDatum(profile,p);
-        (void) SetImageProfileInternal(image,"icc",profile,MagickTrue,
-          exception);
-        profile=DestroyStringInfo(profile);
+        profile=BlobToProfileStringInfo("icc",p,(size_t) count,exception);
+        if (profile != (StringInfo *) NULL)
+          (void) SetImageProfileInternal(image,GetStringInfoName(profile),
+            profile,MagickTrue,exception);
         p+=count;
         break;
       }
@@ -1824,11 +1821,10 @@ static void GetProfilesFromResourceBlock(Image *image,
         /*
           EXIF Profile.
         */
-        profile=AcquireStringInfo((size_t) count);
-        SetStringInfoDatum(profile,p);
-        (void) SetImageProfileInternal(image,"exif",profile,MagickTrue,
-          exception);
-        profile=DestroyStringInfo(profile);
+        profile=BlobToProfileStringInfo("exif",p,(size_t) count,exception);
+        if (profile != (StringInfo *) NULL)
+          (void) SetImageProfileInternal(image,GetStringInfoName(profile),
+            profile,MagickTrue,exception);
         p+=count;
         break;
       }
@@ -1837,11 +1833,10 @@ static void GetProfilesFromResourceBlock(Image *image,
         /*
           XMP Profile.
         */
-        profile=AcquireStringInfo((size_t) count);
-        SetStringInfoDatum(profile,p);
-        (void) SetImageProfileInternal(image,"xmp",profile,MagickTrue,
-          exception);
-        profile=DestroyStringInfo(profile);
+        profile=BlobToProfileStringInfo("xmp",p,(size_t) count,exception);
+        if (profile != (StringInfo *) NULL)
+          (void) SetImageProfileInternal(image,GetStringInfoName(profile),
+            profile,MagickTrue,exception);
         p+=count;
         break;
       }
@@ -1924,6 +1919,9 @@ static MagickBooleanType ValidateXMPProfile(Image *image,
   /*
     Validate XMP profile.
   */
+  const char *artifact=GetImageArtifact(image,"xmp:validate");
+  if (IsStringTrue(artifact) == MagickFalse)
+    return(MagickTrue);
   document=xmlReadMemory((const char *) GetStringInfoDatum(profile),(int)
     GetStringInfoLength(profile),"xmp.xml",NULL,XML_PARSE_NOERROR |
     XML_PARSE_NOWARNING);
@@ -1937,14 +1935,15 @@ static MagickBooleanType ValidateXMPProfile(Image *image,
   return(MagickTrue);
 #else
   (void) profile;
-  (void) ThrowMagickException(exception,GetMagickModule(),MissingDelegateError,
-    "DelegateLibrarySupportNotBuiltIn","`%s' (XML)",image->filename);
+  (void) ThrowMagickException(exception,GetMagickModule(),
+    MissingDelegateWarning,"DelegateLibrarySupportNotBuiltIn","`%s' (XML)",
+    image->filename);
   return(MagickFalse);
 #endif
 }
 
 static MagickBooleanType SetImageProfileInternal(Image *image,const char *name,
-  const StringInfo *profile,const MagickBooleanType recursive,
+  StringInfo *profile,const MagickBooleanType recursive,
   ExceptionInfo *exception)
 {
   char
@@ -1953,19 +1952,30 @@ static MagickBooleanType SetImageProfileInternal(Image *image,const char *name,
   MagickBooleanType
     status;
 
-  StringInfo
-    *clone_profile;
+  size_t
+    length;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
+  assert(profile != (StringInfo *) NULL);
+  assert(name != (const char *) NULL);
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  clone_profile=CloneStringInfo(profile);
-  PatchCorruptProfile(name,clone_profile);
-  if ((LocaleCompare(name,"xmp") == 0) &&
-      (ValidateXMPProfile(image,clone_profile,exception) == MagickFalse))
+  length=GetStringInfoLength(profile);
+  if ((length == 0) || (length > GetMaxProfileSize()))
     {
-      clone_profile=DestroyStringInfo(clone_profile);
+      if (length != 0)
+        (void) ThrowMagickException(exception,GetMagickModule(),
+          ResourceLimitWarning,"ProfileSizeExceedsLimit","`%llu'",
+          (unsigned long long) length);
+      profile=DestroyStringInfo(profile);
+      return(MagickTrue);
+    }
+  PatchCorruptProfile(name,profile);
+  if ((LocaleCompare(name,"xmp") == 0) &&
+      (ValidateXMPProfile(image,profile,exception) == MagickFalse))
+    {
+      profile=DestroyStringInfo(profile);
       return(MagickTrue);
     }
   if (image->profiles == (SplayTreeInfo *) NULL)
@@ -1974,22 +1984,70 @@ static MagickBooleanType SetImageProfileInternal(Image *image,const char *name,
   (void) CopyMagickString(key,name,MagickPathExtent);
   LocaleLower(key);
   status=AddValueToSplayTree((SplayTreeInfo *) image->profiles,
-    ConstantString(key),clone_profile);
-  if (status != MagickFalse)
+    ConstantString(key),profile);
+  if (status == MagickFalse)
+    profile=DestroyStringInfo(profile);
+  else
     {
       if (LocaleCompare(name,"8bim") == 0)
-        GetProfilesFromResourceBlock(image,clone_profile,exception);
+        GetProfilesFromResourceBlock(image,profile,exception);
       else
         if (recursive == MagickFalse)
-          WriteTo8BimProfile(image,name,clone_profile);
+          WriteTo8BimProfile(image,name,profile);
     }
   return(status);
 }
 
+MagickExport StringInfo *AcquireProfileStringInfo(const char *name,
+  const size_t length,ExceptionInfo *exception)
+{
+  StringInfo
+    *profile = (StringInfo *) NULL;
+
+  if (length > GetMaxProfileSize())
+    (void) ThrowMagickException(exception,GetMagickModule(),
+      ResourceLimitWarning,"ProfileSizeExceedsLimit","`%llu'",
+      (unsigned long long) length);
+  else
+    {
+      profile=AcquireStringInfo(length);
+      SetStringInfoName(profile,name);
+    }
+  return(profile);
+}
+
+MagickExport StringInfo *BlobToProfileStringInfo(const char *name,
+  const void *blob,const size_t length,ExceptionInfo *exception)
+{
+  StringInfo
+    *profile;
+
+  profile=AcquireProfileStringInfo(name,length,exception);
+  if (profile != (const StringInfo *) NULL)
+    (void) memcpy(profile->datum,blob,length);
+  return(profile);
+}
+
 MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
   const StringInfo *profile,ExceptionInfo *exception)
 {
-  return(SetImageProfileInternal(image,name,profile,MagickFalse,exception));
+  StringInfo
+    *clone_profile;
+
+  if (profile == (const StringInfo *) NULL)
+    return(MagickFalse);
+  clone_profile=CloneStringInfo(profile);
+  return(SetImageProfileInternal(image,name,clone_profile,MagickFalse,
+    exception));
+}
+
+MagickExport MagickBooleanType SetImageProfilePrivate(Image *image,
+  StringInfo *profile,ExceptionInfo *exception)
+{
+  if (profile == (const StringInfo *) NULL)
+    return(MagickFalse);
+  return(SetImageProfileInternal(image,GetStringInfoName(profile),profile,
+    MagickFalse,exception));
 }
 
 /*
@@ -2493,8 +2551,8 @@ static MagickBooleanType GetXmpOffsets(const StringInfo *profile,
   return(MagickTrue);
 }
 
-static void GetXmpNumeratorAndDenominator(double value,size_t *numerator,
-  size_t *denominator)
+static void GetXmpNumeratorAndDenominator(double value,
+  unsigned long *numerator,unsigned long *denominator)
 {
   double
     df;
@@ -2512,7 +2570,7 @@ static void GetXmpNumeratorAndDenominator(double value,size_t *numerator,
     else
       {
         (*denominator)++;
-        *numerator=(size_t) (value*(*denominator));
+        *numerator=(unsigned long) (value*(*denominator));
       }
     df=*numerator/(double)*denominator;
   }
@@ -2524,17 +2582,19 @@ static void SyncXmpProfile(const Image *image,StringInfo *profile)
     value[MagickPathExtent];
 
   size_t
-    denominator,
     end,
-    numerator,
     start;
 
+  unsigned long
+    denominator,
+    numerator;
+
   *value='\0';
   if (GetXmpOffsets(profile,"tiff:XResolution",&start,&end) != MagickFalse)
     {
       GetXmpNumeratorAndDenominator(image->resolution.x,&numerator,
         &denominator);
-      (void) FormatLocaleString(value,MagickPathExtent,"%zu/%zu",numerator,
+      (void) FormatLocaleString(value,MagickPathExtent,"%lu/%lu",numerator,
         denominator);
       ReplaceXmpValue(profile,start,end,value);
     }
@@ -2545,8 +2605,8 @@ static void SyncXmpProfile(const Image *image,StringInfo *profile)
         {
           GetXmpNumeratorAndDenominator(image->resolution.y,&numerator,
             &denominator);
-          (void) FormatLocaleString(value,MagickPathExtent,"%zu/%zu",numerator,
-            denominator);
+          (void) FormatLocaleString(value,MagickPathExtent,"%lu/%lu",
+            numerator,denominator);
         }
       ReplaceXmpValue(profile,start,end,value);
     }
