@@ -10,7 +10,7 @@
 %                            EEEEE  M   M  F                                  %
 %                                                                             %
 %                                                                             %
-%                  Read Windows Enahanced Metafile Format                     %
+%                   Read Windows Enhanced Metafile Format                     %
 %                                                                             %
 %                              Software Design                                %
 %                              Bill Radcliffe                                 %
@@ -18,7 +18,7 @@
 %                               Dirk Lemstra                                  %
 %                               January 2014                                  %
 %                                                                             %
-%  Copyright @ 2001 ImageMagick Studio LLC, a non-profit organization         %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -653,7 +653,7 @@ static inline void EMFSetDimensions(Image * image,Gdiplus::Image *source)
 
   image->columns=(size_t) floor((Gdiplus::REAL) source->GetWidth()/
     source->GetHorizontalResolution()*image->resolution.x+0.5);
-  image->rows=(size_t)floor((Gdiplus::REAL) source->GetHeight()/
+  image->rows=(size_t) floor((Gdiplus::REAL) source->GetHeight()/
     source->GetVerticalResolution()*image->resolution.y+0.5);
 }
 
@@ -711,7 +711,6 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
-
   image=AcquireImage(image_info,exception);
   if (Gdiplus::GdiplusStartup(&token,&startup_input,NULL) != 
     Gdiplus::Status::Ok)
@@ -728,7 +727,6 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
       Gdiplus::GdiplusShutdown(token);
       ThrowReaderException(FileOpenError,"UnableToOpenFile");
     }
-
   image->resolution.x=source->GetHorizontalResolution();
   image->resolution.y=source->GetVerticalResolution();
   image->columns=(size_t) source->GetWidth();
@@ -773,7 +771,6 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
       Gdiplus::GdiplusShutdown(token);
       return(image);
     }
-
   bitmap=new Gdiplus::Bitmap((INT) image->columns,(INT) image->rows,
     PixelFormat32bppARGB);
   graphics=Gdiplus::Graphics::FromImage(bitmap);
@@ -788,16 +785,14 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
   graphics->DrawImage(source,0,0,(INT) image->columns,(INT) image->rows);
   delete graphics;
   delete source;
-
   rect=Gdiplus::Rect(0,0,(INT) image->columns,(INT) image->rows);
   if (bitmap->LockBits(&rect,Gdiplus::ImageLockModeRead,PixelFormat32bppARGB,
-    &bitmap_data) != Gdiplus::Ok)
-  {
-    delete bitmap;
-    Gdiplus::GdiplusShutdown(token);
-    ThrowReaderException(FileOpenError,"UnableToReadImageData");
-  }
-
+        &bitmap_data) != Gdiplus::Ok)
+    {
+      delete bitmap;
+      Gdiplus::GdiplusShutdown(token);
+      ThrowReaderException(FileOpenError,"UnableToReadImageData");
+    }
   for (y=0; y < (ssize_t) image->rows; y++)
   {
     p=(unsigned char *) bitmap_data.Scan0+(y*abs(bitmap_data.Stride));
@@ -820,7 +815,6 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
     if (SyncAuthenticPixels(image,exception) == MagickFalse)
       break;
   }
-
   bitmap->UnlockBits(&bitmap_data);
   delete bitmap;
   Gdiplus::GdiplusShutdown(token);
