@@ -371,8 +371,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
 
     ssize_t
       count,
-      width,
-      height;
+      height,
+      width;
 
     unsigned short
       bits_per_pixel,
@@ -442,7 +442,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         DestroyBlob(icon_image);
         icon_image->blob=ReferenceBlob(image->blob);
         ReplaceImageInList(&image,icon_image);
-        icon_image->scene=i;
+        icon_image->scene=(size_t) i;
       }
     else
       {
@@ -457,11 +457,14 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         (void) ReadBlobLSBLong(image); /* y_pixels */
         number_colors=ReadBlobLSBLong(image);
         if (number_colors > GetBlobSize(image))
-          ThrowICONReaderException(CorruptImageError,"InsufficientImageDataInFile");
+          ThrowICONReaderException(CorruptImageError,
+            "InsufficientImageDataInFile");
         (void) ReadBlobLSBLong(image); /* colors_important */
         image->alpha_trait=BlendPixelTrait;
-        image->columns=GetICONSize(directory->icons[i]->width,width);
-        image->rows=GetICONSize(directory->icons[i]->height,height);
+        image->columns=(size_t) GetICONSize( directory->icons[i]->width,
+          (size_t) width);
+        image->rows=(size_t) GetICONSize(directory->icons[i]->height,
+          (size_t) height);
         image->depth=bits_per_pixel;
         if (image->depth > 16)
           image->depth=8;
@@ -920,7 +923,7 @@ ModuleExport void UnregisterICONImage(void)
 static Image *AutoResizeImage(const Image *image,const char *option,
   MagickOffsetType *count,ExceptionInfo *exception)
 {
-#define MAX_SIZES 16
+#define MAX_SIZES 11
 
   char
     *q;
@@ -933,7 +936,7 @@ static Image *AutoResizeImage(const Image *image,const char *option,
     *resized;
 
   size_t
-    sizes[MAX_SIZES]={256, 192, 128, 96, 64, 48, 40, 32, 24, 16};
+    sizes[MAX_SIZES] = { 512, 256, 192, 128, 96, 64, 48, 40, 32, 24, 16 };
 
   ssize_t
     i;
@@ -950,7 +953,7 @@ static Image *AutoResizeImage(const Image *image,const char *option,
     while ((isspace((int) ((unsigned char) *p)) != 0))
       p++;
     size=(size_t) strtol(p,&q,10);
-    if ((p == q) || (size < 16) || (size > 256))
+    if ((p == q) || (size < 16) || (size > 512))
       return((Image *) NULL);
     p=q;
     sizes[i++]=size;
@@ -958,7 +961,7 @@ static Image *AutoResizeImage(const Image *image,const char *option,
       p++;
   }
   if (i == 0)
-    i=10;
+    i=MAX_SIZES;
   *count=i;
   for (i=0; i < *count; i++)
   {
@@ -1047,7 +1050,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
       next=image;
       do
       {
-        if ((image->columns > 256L) || (image->rows > 256L))
+        if ((image->columns > 512L) || (image->rows > 512L))
           ThrowWriterException(ImageError,"WidthOrHeightExceedsLimit");
         scene++;
         next=SyncNextImageInList(next);
